@@ -6,6 +6,7 @@ except ImportError:
 
 from io import BytesIO, open
 import os
+from shutil import move
 import warnings
 import uuid
 
@@ -298,6 +299,9 @@ class PSMTemplate():
         :param doc: Page Document
         :type doc: Document
         """
+        canvas.setAuthor("PSM")
+        canvas.setTitle(os.path.basename(self.file_name))
+        canvas.setSubject(os.path.basename(self.file_name))
         self._draw_frame(canvas,doc)
         self._draw_title_block(canvas,doc)
         self._draw_notes(canvas,doc)
@@ -718,7 +722,10 @@ class PSMAppendix():
             writer.addpages(reader.pages)
 
         writer.trailer.Info = IndirectPdfDict(
-                Title=self.appendix_name
+                Title=self.appendix_name,
+                Author="PSM",
+                Subject=self.appendix_name,
+                Creator="psmtemplate"
             )
         writer.write()
 
@@ -726,7 +733,7 @@ class PSMAppendix():
         temp_page_counter = 1
         for fn in self.file_names:
             if self.save_temp_file:
-                os.rename(fn,os.path.abspath(os.path.join(self.path,f"{self.appendix_name}{temp_page_counter}.pdf")))
+                move(fn,os.path.abspath(os.path.join(self.path,f"{self.appendix_name}{temp_page_counter}.pdf")))
             else:
                 os.remove(fn)
             
@@ -820,7 +827,7 @@ if __name__ == "__main__":
 
     a4_portrait_temp = appA.new_page("Description Line 1","Description Line 2")
     
-    for i in range(0,10):
+    for i in range(0,5):
         a4_portrait_temp.add_note(f"Note {i}")
 
     fig = plt.figure(figsize=(4, 3))
@@ -837,20 +844,20 @@ if __name__ == "__main__":
 
     a4_landscape_temp.add_matplotlib_figure(fig)
 
-    for i in range(0,10):
+    for i in range(0,5):
         a4_landscape_temp.add_note(f"Note {i}")
 
 
     a3_portrait_temp = appA.new_page("Description Line 1","Description Line 2",size=A3,direction="portrait")
 
     a3_portrait_temp.add_figure("test/image/test.png")
-    for i in range(0,10):
+    for i in range(0,5):
         a3_portrait_temp.add_note(f"Note {i}")
 
     
     a3_landscape_temp = appA.new_page("Description Line 1","Description Line 2",size=A3,direction="landscape")
     a3_landscape_temp.add_figure("test/image/test.png")
-    for i in range(0,10):
+    for i in range(0,5):
         a3_landscape_temp.add_note(f"Note {i}")
     
     appA.save_temp_file = True
